==> abiword_2.4.6.orig.tar.gz: abiword-2.4.6/abiword-plugins/wp/impexp/OpenDocument/imp/xp/ODi_ManifestStream_ListenerState.h <==
/* AbiSource
 * 
 * Copyright (C) 2006 INdT
 * Author: Daniel d'Andrada T. de Carvalho <daniel.carvalho@indt.org.br>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

#ifndef ODI_MANIFESTSTREAM_LISTENERSTATE_H_
#define ODI_MANIFESTSTREAM_LISTENERSTATE_H_

// Internal includes
#include "ODi_ListenerState.h"

// AbiWord classes
class PD_Document;


/**
 * Class to handle the manifest.xml file.
 */
class ODi_ManifestStream_ListenerState : public ODi_ListenerState {
public:
    
    ODi_ManifestStream_ListenerState(PD_Document* pDocument,
                                ODi_ElementStack& rElementStack);
                                
    virtual ~ODi_ManifestStream_ListenerState() {}
    
    void startElement (const XML_Char* pName, const XML_Char** ppAtts,
                               ODi_ListenerStateAction& rAction);
                               
    void endElement (const XML_Char* pName, ODi_ListenerStateAction& rAction);
                             
    void charData (const XML_Char* pBuffer, int length) {}
    
    bool isDocumentEncripted() const {return m_isDocumentEncripted;};

private:

    PD_Document* m_pDocument;
    
    bool m_isDocumentEncripted;
};

#endif /*ODI_MANIFESTSTREAM_LISTENERSTATE_H_*/

==> abiword_2.6.4.orig.tar.gz: abiword-2.6.4/abiword-plugins/wp/impexp/OpenDocument/imp/xp/ODi_ManifestStream_ListenerState.h <==
/* AbiSource
 * 
 * Copyright (C) 2006 INdT
 * Author: Daniel d'Andrada T. de Carvalho <daniel.carvalho@indt.org.br>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  
 * 02111-1307, USA.
 */

#ifndef ODI_MANIFESTSTREAM_LISTENERSTATE_H_
#define ODI_MANIFESTSTREAM_LISTENERSTATE_H_

// Internal includes
#include "ODi_ListenerState.h"

// AbiWord classes
class PD_Document;


/**
 * Class to handle the manifest.xml file.
 */
class ODi_ManifestStream_ListenerState : public ODi_ListenerState {
public:
    
    ODi_ManifestStream_ListenerState(PD_Document* pDocument,
                                ODi_ElementStack& rElementStack);
                                
    virtual ~ODi_ManifestStream_ListenerState() {}
    
    void startElement (const gchar* pName, const gchar** ppAtts,
                               ODi_ListenerStateAction& rAction);
                               
    void endElement (const gchar* pName, ODi_ListenerStateAction& rAction);
                             
    void charData (const gchar* /*pBuffer*/, int /*length*/) {}
    
    bool isDocumentEncripted() const {return m_isDocumentEncripted;};

private:

    PD_Document* m_pDocument;
    
    bool m_isDocumentEncripted;
};

#endif /*ODI_MANIFESTSTREAM_LISTENERSTATE_H_*/
